## $Id: utils.py 15071 2018-06-30 06:18:27Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Customize general helper utilities for Kofa.
"""
from copy import deepcopy
from kofacustom.nigeria.utils.utils import NigeriaKofaUtils

class CustomKofaUtils(NigeriaKofaUtils):
    """A collection of methods subject to customization.
    """

    PAYMENT_CATEGORIES = {
        'schoolfee': 'Tuition and Exams Fee',
        'clearance': 'Acceptance Fee',
        'bed_allocation': 'Accommodation Booking Fee',
        'hostel_maintenance': 'Hostel Maintenance Fee',
        'application': 'Application Fee',
        'ict_entre': 'ICT and Entrepreneur Fee',
        'logbook_combo': 'Logbook Combo Fee',
        'siwess_combo': 'SIWESS Combo Fee',
        'transcript': 'Transcript Fee',
        'certificate': 'Certificate Fee',
        'certificate_confirm': 'Certificate Confirmation Fee',
        'late_registration': 'Late Course Registration Fee',
        'final_clearance': 'Final Clearance Fee',
        }

    SELECTABLE_PAYMENT_CATEGORIES = deepcopy(PAYMENT_CATEGORIES)

    BALANCE_PAYMENT_CATEGORIES = {
        'schoolfee': 'Tuition and Exams Fee',
        'ict_entre': 'ICT and Entrepreneur Fee',
        'certificate_confirm': 'Certificate Confirmation Fee',
        'final_clearance': 'Final Clearance Fee',
        }

    REPORTABLE_PAYMENT_CATEGORIES = {
        'schoolfee': 'Tuition and Exams Fee',
        'clearance': 'Acceptance Fee',
        #'bed_allocation': 'Accommodation Booking Fee',
        'hostel_maintenance': 'Hostel Maintenance Fee',
        'ict_entre': 'ICT and Entrepreneur Fee',
        'logbook_combo': 'Logbook Combo Fee',
        'siwess_combo': 'SIWESS Combo Fee',
        #'transcript': 'Transcript Fee',
        'certificate': 'Certificate Fee',
        'certificate_confirm': 'Certificate Confirmation Fee',
        'late_registration': 'Late Course Registration Fee',
        'final_clearance': 'Final Clearance Fee',
        }

    STUDY_MODES_DICT = {
        'ume_ft': 'UME Full Time',
        'ug_ft': 'Undergraduate Full Time',
        'ug_pt': 'Undergraduate Part Time',
        'dp_pt': 'Diploma Part Time',
        'ct_ft': 'Certificate Full Time',
        'dp_ft': 'Diploma Full Time',
        'de_ft': 'Direct Entry Full Time',
        'de_pt': 'Direct Entry Part Time',
        'nd_ft': 'National Diploma Full Time',
        'nd_pt': 'National Diploma Part Time',
        'hnd_ft': 'Higher National Diploma Full Time',
        'hnd_pt': 'Higher National Diploma Part Time',
        'pg_ft': 'Postgraduate Full Time',
        'pg_pt': 'Postgraduate Part Time',
        'pgd_ft': 'Postgraduate Diploma Full Time',
        'pgd_pt': 'Postgraduate Diploma Part Time',
        'special_pg_pt': 'Special Postgraduate Part Time',
        'nce_ft': 'NCE Full Time',
        'nce_pt': 'NCE Part Time',
        'ug_sw': 'Undergraduate Sandwich',
        'nce_sw': 'NCE Sandwich',
        'jm_ft': 'Joint Matriculation Full Time',
        'ph_ft': 'Post Higher Education Full Time',
        'transfer_pt': 'Transfer Part Time',
        'transfer_ft': 'Transfer Full Time',
        'ct_pt': 'Certificate Part Time',
        'rmd_ft': 'Remedial with deficiencies',
        'rm_ft': 'Remedial',
        'transfer': 'Transfer',
        'prence': 'Pre-NCE',
        'prend': 'Pre-ND',
        'pce': 'PCE',
        'pd_ft': 'Professional Diploma in Education',
        'found': 'Foundation',
        'no': 'no application',
        }

    MODE_GROUPS = {
        'All': ('all',),
        'Undergraduate Full-Time': ('ug_ft',),
        'Undergraduate Part-Time': ('ug_pt',),
        'Postgraduate Full-Time': ('pg_ft',),
        'Postgraduate Part-Time': ('pg_pt',),
        }
